@@ -57,7 +57,11 @@ def dummy_failure():
         (BoostTestFacade(), "boost_success", ["boost_success"]),
         (BoostTestFacade(), "boost_error", ["boost_error"]),
         (BoostTestFacade(), "boost_fixture_setup_error", ["boost_fixture_setup_error"]),
-        (Catch2Facade(), "catch2_success", ["Factorials are computed"]),
+        (
+            Catch2Facade(),
+            "catch2_success",
+            ["Factorials are computed", "Passed Sections"],
+        ),
     ],
 )
 def test_list_tests(facade, name, expected, exes):
@@ -610,6 +614,9 @@ def test_catch2_failure(exes):
 
     assert fail1.get_file_reference() == ("catch2_failure.cpp", 9)
 
+    failures, _ = facade.run_test(exes.get("catch2_failure"), "Failed Sections")
+    assert len(failures) == 2
+
 
 class TestError:
     def test_get_whitespace(self):
